@@ -74,6 +74,26 @@ class Arkivist:
         if self.autosave and self.save_to_file:
             update_file(self.filepath, self.collection, self.indent, self.sort, self.reverse, self.encoding)
         return self
+    
+    def default(self, key, old, new):
+        """
+            If key equals to old value, update to new value
+            ...
+            Parameters
+            ---
+            key: string, int
+                any unique value
+            old: any data type
+                old value to check
+            new: any data type
+                new value to replace    
+        """
+        self.child_key = None
+        if self.collection.get(key, old) == old:
+            self.collection.update({key: new})
+        if self.autosave and self.save_to_file:
+            update_file(self.filepath, self.collection, self.indent, self.sort, self.reverse, self.encoding)
+        return self
 
     def fetch(self, url):
         """
@@ -430,12 +450,12 @@ def update_file(filepath, data, indent=4, sort=False, reverse=False, encoding="u
         try:
             indent = get_int(indent, min=1, max=4)
             with open(filepath, "w+", encoding=encoding) as file:
-                file.write(json.dumps(data, indent=indent, ensure_ascii=False, encoding=encoding))
+                file.write(json.dumps(data, indent=indent, ensure_ascii=False))
         except Exception as e:
             print(e)
             pass
 
-def read(filepath, encoding):
+def read(filepath, encoding="utf-8"):
     """
         Read JSON file and converts to a Python dictionary.
         ...
@@ -445,7 +465,7 @@ def read(filepath, encoding):
             path to the json file
     """
     try:
-        with open(filepath, "r", encoding) as file:
+        with open(filepath, "r", encoding=encoding) as file:
             return json.loads(file.read())
     except:
         return {}
