@@ -1,10 +1,12 @@
-from arkivist import Arkivist
+from arkivist import Arkivist, version
 from arkivist.arkivist import update_file, read
 
 
 ## Example #1
 print("\nTest #1")
-people = read("tests.json", encoding="utf-8")
+
+print(version.version)
+people = read("tests.json")
 
 person = {}
 person.update({"name": "Abc"})
@@ -20,14 +22,14 @@ people.update({"xyz": person})
 
 update_file("tests.json", people, indent=2, sort=True, reverse=True)
 
-"""
+
 ## Example #2 / autosave = True (default)
 print("\nTest #2")
-people = Arkivist("tests.json")
+people = Arkivist("tests.json") #, encoder="utf-8")
 
 person = {}
-person.update({"name": "Juan"})
-people.update({"juan": person})
+person.update({"name": "Ñino"})
+people.update({"ñino": person})
 
 people.set("boy", {"name": "Boy"})
 people.set("girl", {"name": "Girl"})
@@ -36,6 +38,8 @@ print("Show all items (unsorted): ", people.show())
 print("Show all items (sorted): ", people.show(sort=True))
 print("Show all items (reverse): ", people.show(sort=True, reverse=True))
 
+
+
 ## Example #3 / autosave = False
 print("\nTest #3")
 people = Arkivist("tests.json", autosave=False)
@@ -228,4 +232,11 @@ print("People2:", people2.show())
 people2.reload()
 print("People2", people2.show())
 
-"""
+## Example #15
+print("\nTest #15")
+hello = Arkivist("hello.json")
+hello.default("hello", "", "world")
+hello.default("hello", "", "friend")
+print("Test", hello.show())
+
+
